#ifndef GOOGLEX_GCAM_CREATIVE_CAMERA_PORTRAIT_MODE_PORTRAIT_CROS_WRAPPER_H_
#define GOOGLEX_GCAM_CREATIVE_CAMERA_PORTRAIT_MODE_PORTRAIT_CROS_WRAPPER_H_

// This header provides public API of the portrait mode feature for Chromium OS.
// Do not include any other headers if possible.

#include <cstdint>
#include <memory>

namespace creative_camera {

class PortraitProcessor;
class PortraitSegmenter;

class PortraitCrosWrapper {
 public:
  PortraitCrosWrapper();
  ~PortraitCrosWrapper();

  // Initializes the portrait processor. Should be called before Process().
  // Returns true on success.
  bool Init();

  // Processes a portrait image, returning a background defocused result.
  //
  // `id` should be a unique identifier for this portrait. It should not be
  // duplicated within the lifetime of this PortraitProcessor.
  //
  // `width` and `height` specifies the dimensions of input and output images.
  // `orientation` can be 0, 90, 180, or 270 in degrees counter-clockwise.
  //
  // `rgb_input_data` and `rgb_output_data` point to memory of size
  // `width`x`height`x3 for storing input and output images in RGB planar
  // format. The memory must remain valid until Process() returns.
  //
  // Returns true on success.
  bool Process(int64_t id, int width, int height, int orientation,
               const uint8_t* rgb_input_data, uint8_t* rgb_output_data);

 private:
  std::unique_ptr<PortraitProcessor> processor_;
  std::unique_ptr<PortraitSegmenter> segmenter_;
};

}  // namespace creative_camera

#endif  // GOOGLEX_GCAM_CREATIVE_CAMERA_PORTRAIT_MODE_PORTRAIT_CROS_WRAPPER_H_
